# -*- coding: utf-8 -*-
""" Hydrochemistry: Constructs multiple Stiff plots

    - Prepare an input text file. Observations are expected have meq/l units with parameters in the order: Cl, HCO3, SO4, Na+K, Ca, Mg

    - Example input file. If observations are missing, label them as -9999:

    Type Cl HCO3 SO4 NaK Ca Mg EC NO3 Sicc
    1 1.72 4.02 0.58 1.40 4.53 0.79 672.00 0.40 0.21
    2 0.90 1.28 0.54 0.90 1.44 0.74 308.00 0.36 0.56
    2 4.09 4.29 0.38 3.38 4.74 0.72 884.00 0.08 0.15

    - Insert the correct file name and delimiter in the loadtxt() statement

    - Specify legend for figure

    - Run the script and look at the plot
    
    Development date: 8/5/2011
"""

__author__ = "B.M. van Breukelen <b.m.vanbreukelen@vu.nl>"
__version__ = "1.0"
__date__ = "Nov 2012"


# First always functions need to be imported
# -------------------------------------------------------------------------------- #

from pylab import * # the pylab module combines Pyplot (MATLAB type of plotting) with Numpy into a single namespace

# Specify locations of files and open the files
# -------------------------------------------------------------------------------- #

# Observations
# Observations are expected have meq/l units with parameters in the order: Cl, HCO3, SO4, Na+K, Ca, Mg
obs=loadtxt('watersamples.txt', , delimiter='\t', comments='#') # first row with headers is skipped, matrix with data is assigned to obs
obs[obs == -9999] = NaN # if observations are missing, label them as -9999 (for example) in excel and make them Not a Number (NaN)

nosamples = 18 # # number samples
ncol = 5 # number of columns of subplot
nrow = 4 # number of rows of subplot

# Column Index for parameters
Cl = 1
HCO3 = Cl+1
SO4 = Cl+2
NaK = Cl+3
Ca = Cl+4
Mg = Cl+5

# Change default settings for figures
# -------------------------------------------------------------------------------- #
rc('savefig', dpi = 300)
rc('xtick', labelsize = 10)
rc('ytick', labelsize = 10)
rc('font', size = 12)
rc('legend', fontsize = 12)
rc('figure', figsize = (14,14)) # defines size of Figure window

markersize = 12
linewidth = 2
xtickpositions = [-5.,-3.,-1.,0.,1.,3.,5.] # desired xtickpositions for graphs

# Make Figure
# -------------------------------------------------------------------------------- #

figure()

for sID in range(0, nosamples):
    subplot(nrow,ncol,sID+1)
    hold(True)
    # define x coordinates of fill
    x=[-obs[sID, NaK], -obs[sID, Ca], -obs[sID, Mg], obs[sID, SO4], obs[sID ,HCO3], obs[sID, Cl], -obs[sID, NaK]]
    y=[3,2,1,1,2,3,3]

    # Stiff plots with color depending on water type
    if obs[sID, 0] == 1:
        h1=fill(x, y, 'r')
    if obs[sID, 0] == 2:
        h2=fill(x, y, 'b')
    if obs[sID, 0] == 3:
        h3=fill(x, y, 'c')
    if obs[sID, 0] == 4:
        h4=fill(x, y, 'g')
    if obs[sID, 0] == 5:
        h5=fill(x, y, 'm')
    
    plot([0,0], [1,3],'w')
    
    # NO3 plotted as extra circle
    h6=plot(5.*obs[sID, 8], 1, 'yo', ms=markersize)
    
    # SI Calcite plotted as extra square
    h7=plot(2*obs[sID, 9], 2, 'ks', ms=markersize)

    # Add legend at one selected stiff diagram    
    if sID == 1:
        text(-4.5,2.9,'Na+K')
        text(-4.5,1.9,'Ca')
        text(-4.5,0.9,'Mg')
        text(2.5,2.9,'Cl')
        text(2.5,1.9,'HCO3')
        text(2.5,0.9,'SO4')
        #xlabel('(meq/L)')
        xticks(xtickpositions)
        xticklabels=('5','3','1','0','-1','-3','-5')

    ylim(0.8, 3.2)
    xlim(-5.2, 5.2)
    xticks(xtickpositions)
    setp(gca(), yticks=[], yticklabels=[])

# Legend for Figure
figlegend((h1,h2,h3,h4,h5,h6,h7),('Dinkel','Tributaries NL','Tributaries G','Lakes','Groundwater','NO3x5','SI_cc x 2'), ncol=7, shadow=False, fancybox=True, loc='lower center', handlelength = 3)

# adjust position subplots
subplots_adjust(left=0.05, bottom=0.1, right=0.95, top=0.95, wspace=0.2, hspace=0.30)
show()
